<?php

namespace Drupal\content_save_confirm\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for Content Save Confirm module.
 */
class ContentSaveConfirmConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['content_save_confirm.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_save_confirm_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('content_save_confirm.settings');

    $form['confirmation_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Confirmation Message'),
      '#description' => $this->t('The message to display in the confirmation dialog.'),
      '#default_value' => $config->get('confirmation_message') ?: $this->t('Are you sure you want to save this content?'),
      '#rows' => 3,
      '#required' => TRUE,
    ];

    $form['enabled_forms'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Enabled Form IDs'),
      '#description' => $this->t('Enter form IDs (one per line) where the confirmation dialog should appear. Common examples:<br/>
        - node_article_form (Article content type)<br/>
        - node_page_form (Page content type)<br/>
        - node_article_edit_form (Article edit form)<br/>
        - node_page_edit_form (Page edit form)<br/>
        - user_register_form<br/>
        - user_form'),
      '#default_value' => is_array($config->get('enabled_forms')) ? implode("\n", $config->get('enabled_forms')) : '',
      '#rows' => 8,
    ];

    $form['form_id_help'] = [
      '#type' => 'details',
      '#title' => $this->t('How to find Form IDs'),
      '#description' => $this->t('To find form IDs, you can:<br/>
        1. Enable Devel module and use dpm($form_id) in hook_form_alter()<br/>
        2. Check browser developer tools for form element attributes<br/>
        3. Look at the form class name (usually ends with "Form")<br/>
        4. For content types: node_[content_type]_form for add, node_[content_type]_edit_form for edit'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $enabled_forms = $form_state->getValue('enabled_forms');
    
    // Convert textarea input to array
    $enabled_forms_array = [];
    if (!empty($enabled_forms)) {
      $enabled_forms_array = array_filter(array_map('trim', explode("\n", $enabled_forms)));
    }

    $this->config('content_save_confirm.settings')
      ->set('confirmation_message', $form_state->getValue('confirmation_message'))
      ->set('enabled_forms', $enabled_forms_array)
      ->save();

    parent::submitForm($form, $form_state);
  }

}